@@ -47,7 +47,9 @@ class Box(Graph):
 
         def format_maybe_quartile(x):
             if is_list_like(x):
-                if len(x) == 5:
+                if self.mode == "extremes":
+                    return 'Min: %s Q1: %s Q2: %s Q3: %s Max: %s' % tuple(map(sup, x))
+                else:
                     return 'Q1: %s Q2: %s Q3: %s' % tuple(map(sup, x[1:4]))
             else:
                 return sup(x)
@@ -59,7 +61,7 @@ class Box(Graph):
         within the rendering process
         """
         for serie in self.series:
-            serie.values = self._box_points(serie.values)
+            serie.values = self._box_points(serie.values, self.mode)
 
         if self._min:
             self._box.ymin = min(self._min, self.zero)
@@ -84,13 +86,14 @@ class Box(Graph):
         """
         Plot the series data
         """
-        for index, serie in enumerate(self.series):
-            self._boxf(self._serie(index), serie, index)
+        for serie in self.series:
+            self._boxf(serie)
 
-    def _boxf(self, serie_node, serie, index):
+    def _boxf(self, serie):
         """
         For a specific series, draw the box plot.
         """
+        serie_node = self.svg.serie(serie)
         # Note: q0 and q4 do not literally mean the zero-th quartile
         # and the fourth quartile, but rather the distance from 1.5 times
         # the inter-quartile range to Q1 and Q3, respectively.
@@ -104,7 +107,7 @@ class Box(Graph):
             metadata)
         val = self._format(serie.values)
 
-        x_center, y_center = self._draw_box(box, serie.values, index)
+        x_center, y_center = self._draw_box(box, serie.values, serie.index)
         self._tooltip_data(box, val, x_center, y_center, classes="centered")
         self._static_value(serie_node, val, x_center, y_center)
 
@@ -160,10 +163,15 @@ class Box(Graph):
             sum(quartiles) / len(quartiles)))
 
     @staticmethod
-    def _box_points(values):
+    def _box_points(values, mode='1.5IQR'):
         """
-        Return a 5-tuple of Q1 - 1.5 * IQR, Q1, Median, Q3,
+        Default mode: (mode='1.5IQR' or unset)
+            Return a 5-tuple of Q1 - 1.5 * IQR, Q1, Median, Q3,
         and Q3 + 1.5 * IQR for a list of numeric values.
+        Extremes mode: (mode='extremes')
+            Return a 5-tuple of minimum, Q1, Median, Q3,
+        and maximum for a list of numeric values.
+
 
         The iterator values may include None values.
 
@@ -203,6 +211,10 @@ class Box(Graph):
                     q3 = 0.25 * s[3*m+1] + 0.75 * s[3*m+2]
 
             iqr = q3 - q1
-            q0 = q1 - 1.5 * iqr
-            q4 = q3 + 1.5 * iqr
+            if mode == 'extremes':
+                q0 = min(s)
+                q4 = max(s)
+            else:
+                q0 = q1 - 1.5 * iqr
+                q4 = q3 + 1.5 * iqr
             return q0, q1, q2, q3, q4
