@@ -21,7 +21,7 @@ Various utils
 
 """
 from __future__ import division
-from pygal._compat import to_str, u, is_list_like
+from pygal._compat import u, is_list_like, to_unicode
 import re
 from decimal import Decimal
 from math import floor, pi, log, log10, ceil
@@ -241,7 +241,7 @@ def decorate(svg, node, metadata):
         if key == 'xlink' and isinstance(value, dict):
             value = value.get('href', value)
         if value:
-            svg.node(node, 'desc', class_=key).text = to_str(value)
+            svg.node(node, 'desc', class_=key).text = to_unicode(value)
     return node
 
 
@@ -318,17 +318,17 @@ def safe_enumerate(iterable):
         if v is not None:
             yield i, v
 
-from pygal.serie import Serie
 
-
-def prepare_values(raw, config, cls):
+def prepare_values(raw, config, cls, offset=0):
     """Prepare the values to start with sane values"""
+    from pygal.serie import Serie
+    from pygal.config import SerieConfig
     from pygal.graph.datey import DateY
     from pygal.graph.histogram import Histogram
     from pygal.graph.worldmap import Worldmap
     from pygal.graph.frenchmap import FrenchMapDepartments
     if config.x_labels is None and hasattr(cls, 'x_labels'):
-        config.x_labels = cls.x_labels
+        config.x_labels = list(map(to_unicode, cls.x_labels))
     if config.zero == 0 and issubclass(cls, (Worldmap, FrenchMapDepartments)):
         config.zero = 1
 
@@ -349,13 +349,14 @@ def prepare_values(raw, config, cls):
 
     raw = [(
         title,
-        list(raw_values) if not isinstance(raw_values, dict) else raw_values
-    ) for title, raw_values in raw]
+        list(raw_values) if not isinstance(raw_values, dict) else raw_values,
+        serie_config_kwargs
+    ) for title, raw_values, serie_config_kwargs in raw]
 
-    width = max([len(values) for _, values in raw] +
+    width = max([len(values) for _, values, _ in raw] +
                 [len(config.x_labels or [])])
 
-    for title, raw_values in raw:
+    for title, raw_values, serie_config_kwargs in raw:
         metadata = {}
         values = []
         if isinstance(raw_values, dict):
@@ -399,7 +400,11 @@ def prepare_values(raw, config, cls):
             else:
                 value = adapter(value)
             values.append(value)
-        series.append(Serie(title, values, metadata))
+        serie_config = SerieConfig()
+        serie_config(**config.to_dict())
+        serie_config(**serie_config_kwargs)
+        series.append(
+            Serie(offset + len(series), title, values, serie_config, metadata))
     return series
 
 
